#!/bin/bash

interval="0.0 2.0"
twdir="tw"
VER=84

usage() {
   echo "Usage: calctw -r R0 -p p0 -w sigma -e eshift -i inputfile"
   echo "              [ -t jtot ] [ -n namedir ] [ -c tcut ] [ -I npoints ]"
   exit 1
}

while getopts "r:p:w:e:i:t:n:c:I:h" opt; do
   case $opt in
   h)  usage ;;
   r)  r0=$OPTARG ;;
   p)  p0=$OPTARG ;;
   w)  sigma=$OPTARG ;;
   e)  eshift=$OPTARG ;;
   i)  propinp="$OPTARG" ;;
   t)  jtot=$OPTARG ;;
   n)  namedir=$OPTARG ;;
   c)  tcut="-t $OPTARG -cos 2" ;;
   I)  npopt="-p $OPTARG" ;;
   esac
done

test "$r0" || usage
test "$p0" || usage
test "$sigma" || usage
test "$eshift" || usage
test "$propinp" || usage

if [ -z "$jtot" ]; then
   # try to get it from input file
   jtot=`grep '^ *jtot *=' $propinp | head -n 1 | sed -e 's/^ *jtot *= *\([0-9]\+\).*$/\1/'`
   if [ -z "$jtot" ]; then
      echo "WARNING: could not determine jtot, using jtot=0"
      jtot=0
   fi
fi

# try to get name directory from input file
if [ -z "$namedir" ]; then
   namedir=`awk '/^ *name *=/ {print $3}' $propinp`
   if [ -z "$namedir" ]; then
      echo "ERROR: could not determine name directory. Use option -n."
      exit 1
   fi
fi

# make paths absolute
namedir="$PWD/$namedir"
propinp="$PWD/$propinp"

# check name directory
if [ ! -d "$namedir" ]; then
   echo "Name directory '$namedir' doesn't exist!"
   exit 1
fi

export LC_ALL=C # shut up perl

# create TW directory
if [ ! -d "$twdir" ]; then
   mkdir "$twdir"
fi

cd "$twdir"
for j1 in 2 4; do
   for j2 in `seq 0 2 $j1`; do
      for m1 in `seq -$j1 $j1`; do
         [ $m1 = "-0" ] && m1=0
         for m2 in `seq -$j2 $j2`; do
            [ $m2 = "-0" ] && m2=0
            for n1 in 1 2; do for n2 in 1 2; do
              [ $[$n1+$n2] -gt 3 ] && continue
              # check whether the symmetric case has already been done
              suffix="$j2$m2$n2+$j1$m1$n1"
              if [ -f "tw_$suffix" ]; then
                cp "tw_$suffix" "tw_$j1$m1$n1+$j2$m2$n2"
                continue
              fi
              suffix="$j1$m1$n1+$j2$m2$n2"
              genrefwf.sh -r $r0 -p $p0 -w $sigma -t $jtot \
                 -j $j1 -m $m1 -n $n1 -J $j2 -M $m2 -N $n2 -i "$propinp"
              crosscorr$VER -o "cross_$suffix" -f "$namedir/" \
                 -r "inwf_$suffix/" >/dev/null
              rm -f crscr.log
              twprob$VER $tcut $npopt -o "tw_$suffix" -e $eshift ev $interval ev \
                 "cross_$suffix" "$namedir/enerd" "inwf_$suffix/enerd"
            done; done
         done
      done
      # do summation over m
      sumcol4 tw_${j1}*+${j2}* >| msum_${j1}+${j2}.pl
   done
done

# clean up
rm -rf inwf_*/{dvr,log,op.log,restart,timing} oper_*
tar czf inwf.tgz inwf_* && rm -rf inwf_*
tar czf cross.tgz cross_* && rm -f cross_*
tar czf tw.tgz tw_* && rm -f tw_*
