#!/bin/bash
VER=84  # set MCTDH version number
JTOT=20 # total angular momentum quantum number

export PATH="$PWD/bin:$PATH"

# create the potential fit
cd BMKPE
projection$VER -mnd -w proj
for POT in a000 a200 a020 a220 a221 a222; do
    potfit$VER -mnd -w $POT
done
cd ..


# determine the energy shift (must be done for J=0)
mctdh$VER -mnd -w inwf_J00
ESHIFT=$(
    cat inwf_J00/log \
    | perl -ne '/^energy shift.*\s+-(\S+) ev/i && print $1' )


# create fit for cpp/cmm surfaces
for SRF in cmm cpp; do
    mpp jtot=$JTOT < "${SRF}.in" >| "${SRF}_J${JTOT}.inp"
    potfit$VER -mnd -w "${SRF}_J${JTOT}"
done


# start propagation in h-proj mode
mpp jtot=$JTOT pwd="$PWD" < "prop_strt.in" >| "prop_J${JTOT}_strt.inp"
mctdh$VER -mnd -w "prop_J${JTOT}_strt"
# extract final time
TINIT=$(
    tail -1 "prop_J${JTOT}_strt/speed" \
    | awk '{print $1}' )


# finish propagation in proj-h mode
mpp jtot=$JTOT pwd="$PWD" tinit="$TINIT" < "prop_rest.in" >| "prop_J${JTOT}_rest.inp"
mctdh$VER -mnd -w "prop_J${JTOT}_rest"
# copy energy distribution from start run
cp "prop_J${JTOT}_strt/enerd" "prop_J${JTOT}_rest/"


# calculate transition probabilities and sum them
calctw.sh -r 10.0 -p 9.3 -w 0.15 -e "$ESHIFT" \
    -i "prop_J${JTOT}_strt.inp" -n "prop_J${JTOT}_rest" \
    -c 200 -t ${JTOT} -I 2000
