# map quantum numbers to SPFs -- see MCTDH log file
my $rot_map = {
    "0 0"  => 1,
    "2 0"  => 2,
    "2 1"  => 3,
    "2 -1" => 4,
    "2 2"  => 5,
    "2 -2" => 6,
    "4 0"  => 7,
    "4 1"  => 8,
    "4 -1" => 9,
    "4 2"  => 10,
    "4 -2" => 11,
    "4 3"  => 12,
    "4 -3" => 13,
    "4 4"  => 14,
    "4 -4" => 15
};


sub acoeff {
    # assign parameters
    my ($j1,$m1,$n1,$j2,$m2,$n2) = @_;
    my ($acoeff,$spf3,$spf4);

    # look up (j1,m1) and (j2,-m2) for mode 3
    $spf3 = $rot_map->{$j1." ".$m1};
    $spf3a = $rot_map->{$j2." ".(-$m2)};
    # look up (j2,m2) and (j1,-m1) for mode 4
    $spf4 = $rot_map->{$j2." ".$m2};
    $spf4a = $rot_map->{$j1." ".(-$m1)};

    if ($j1==$j2 and $m1==-$m2) {
        # in this case only one term remains
        $acoeff = "    1 1 $spf3 $spf4 (1.d0,0.d0)";
        
    } elsif ($j1==$j2 and $n1==$n2) {
        # in this case Phi- (2nd SPF for mode 2) is zero
        $acoeff = <<"EOF";
    1 1 $spf3 $spf4 (1.d0,0.d0)
    1 1 $spf3a $spf4a (1.d0,0.d0)
EOF

    } else {
        # contributions from both Phi+ and Phi-
        $acoeff = <<"EOF";
    1 1 $spf3 $spf4 (1.d0,0.d0)
    1 2 $spf3 $spf4 (1.d0,0.d0)
    1 1 $spf3a $spf4a (1.d0,0.d0)
    1 2 $spf3a $spf4a (-1.d0,0.d0)
EOF
    }

    return $acoeff;
}


sub dj_acoeff {
    my ($j1,$m1,$j2,$m2) = @_;
    my ($acoeff,$spf2,$spf3);

    # look up (j1,m1) and (j2,-m2) for mode (AL,k1)
    $spf2 = $rot_map->{$j1." ".$m1};
    $spf2a = $rot_map->{$j2." ".(-$m2)};
    # look up (j2,m2) and (j1,-m1) for mode (BE,k2)
    $spf3 = $rot_map->{$j2." ".$m2};
    $spf3a = $rot_map->{$j1." ".(-$m1)};

    if ($j1==$j2 and $m1==-$m2) {
        # in this case only one term remains
        $acoeff = "    1 $spf2 $spf3 (1.d0,0.d0)";
    } else {
        # both terms needed
        $acoeff = "    1 $spf2 $spf3 (1.d0,0.d0)\n";
        $acoeff.= "    1 $spf2a $spf3a (1.d0,0.d0)";
    }
    return $acoeff;
}

1;
